@@ -59,6 +59,11 @@ from .meta import (
     PropValueType,
     ValidationResult,
 )
+from .natural_query import (
+    HumanQuery,
+    NaturalQueryParser,
+    query,
+)
 from .node import (
     Node,
     NodeDetails,
@@ -129,6 +134,10 @@ __all__ = [
     "IFluentOperation",
     "ElementFilter",
     "FluentQuery",
+    # Natural language query
+    "HumanQuery",
+    "NaturalQueryParser",
+    "query",
     # REST client classes
     "RestGraphApiClient",
     "RestDataStorage",
