@@ -145,3 +145,55 @@ class Edge(BaseElement):
         # Mark as updated and emit event
         self.mark_updated()
         self.emit("edge_reversed")
+
+    def to_dict_api(self) -> dict:
+        """Convert edge to dictionary for API response with classId format and name in properties."""
+        from typing import Any
+
+        def convert_to_serializable(obj: Any) -> Any:
+            """Convert generators and other non-serializable objects to serializable forms."""
+            if isinstance(obj, dict):
+                return {k: convert_to_serializable(v) for k, v in obj.items()}
+            elif isinstance(obj, (list, tuple)):
+                return [convert_to_serializable(item) for item in obj]
+            elif hasattr(obj, "__iter__") and not isinstance(obj, (str, bytes)):
+                # Convert generators and other iterables to lists
+                try:
+                    return [convert_to_serializable(item) for item in obj]
+                except TypeError:
+                    return obj
+            return obj
+
+        # Build the properties dict
+        properties_dict = {}
+        if self.properties:
+            if isinstance(self.properties, dict):
+                properties_dict = convert_to_serializable(self.properties)
+            else:
+                # Convert properties object to dict
+                props_dict = (
+                    vars(self.properties)
+                    if hasattr(self.properties, "__dict__")
+                    else dict(self.properties)
+                )
+                properties_dict = convert_to_serializable(props_dict)
+
+        # Build attributes dict
+        attributes_dict = {}
+        if self.attributes:
+            attributes_dict = convert_to_serializable(self.attributes)
+
+        result = {
+            "id": self.id,
+            "type": self.type.value if hasattr(self.type, "value") else str(self.type),
+            "classId": self.class_id,
+            "properties": properties_dict,
+            "source": self.source,
+            "from_id": self.from_id,
+            "to_id": self.to_id,
+        }
+
+        if attributes_dict:
+            result["attributes"] = attributes_dict
+
+        return result
